aboutsummaryrefslogtreecommitdiffstats
path: root/src/classes/share
diff options
context:
space:
mode:
authorKevin Rushforth <[email protected]>2004-12-21 19:05:45 +0000
committerKevin Rushforth <[email protected]>2004-12-21 19:05:45 +0000
commit451909b8beecf3a915587538495dd47d4e635d08 (patch)
tree0f82ae46c7ab4b54f732e7d3c677657d132c12c3 /src/classes/share
parentf5a0736664ce8b48fa7024e3655e2796fc339d80 (diff)
Issue number: 91
Implemented feature request for Issue 91: Added two new properties, native.vendor and native.renderer, which return the name of the vendor and the renderer string from the native library. Currently D3D sets these properties to "<UNKNOWN>". git-svn-id: https://svn.java.net/svn/j3d-core~svn/trunk@93 ba19aa83-45c5-6ac9-afd3-db810772062c
Diffstat (limited to 'src/classes/share')
-rw-r--r--src/classes/share/javax/media/j3d/Canvas3D.java14
1 files changed, 10 insertions, 4 deletions
diff --git a/src/classes/share/javax/media/j3d/Canvas3D.java b/src/classes/share/javax/media/j3d/Canvas3D.java
index 0fabc33..55821e0 100644
--- a/src/classes/share/javax/media/j3d/Canvas3D.java
+++ b/src/classes/share/javax/media/j3d/Canvas3D.java
@@ -589,8 +589,10 @@ public class Canvas3D extends Canvas {
// constructor to allow Java 3D to extend it.
static Hashtable fbConfigTable = new Hashtable();
- // The native graphics version and renderer information
- String nativeGraphicsVersion = null;
+ // The native graphics version, vendor, and renderer information
+ private String nativeGraphicsVersion = "<UNKNOWN>";
+ private String nativeGraphicsVendor = "<UNKNOWN>";
+ private String nativeGraphicsRenderer = "<UNKNOWN>";
NativeWSInfo nativeWSobj = new NativeWSInfo();
boolean firstPaintCalled = false;
@@ -3546,10 +3548,14 @@ public class Canvas3D extends Canvas {
values.add(new Integer(numTexUnitSupported));
keys.add("native.version");
- if(nativeGraphicsVersion == null)
- nativeGraphicsVersion = "";
values.add(nativeGraphicsVersion);
+ keys.add("native.vendor");
+ values.add(nativeGraphicsVendor);
+
+ keys.add("native.renderer");
+ values.add(nativeGraphicsRenderer);
+
// Now Create read-only properties object
queryProps =
new J3dQueryProps((String[]) keys.toArray(new String[0]),